@@ -13,7 +13,7 @@ use HTTP::Date;
 use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.143_03';
+our $VERSION = '0.143_04';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
@@ -201,7 +201,8 @@ sub not_defined {
 		url	=> 'http://www.rod.sladen.org.uk/iridium.htm',
 	    },
 	    'spaceflight.nasa.gov'	=> {
-		url	=> 'http://spaceflight.nasa.gov',
+		# url	=> 'http://spaceflight.nasa.gov',
+		url	=> 'https://spaceflight.nasa.gov/realdata/elements/index.html'
 	    },
 	    'www.amsat.org'	=> {
 		url	=> 'http://www.amsat.org/',
